from typing import List


def create_html_table(header: List[str], rows: List[List[str]]) -> str:
    """ Generate an HTML table from a list of headers,
    and a 2d array of table rows. The returned HTML will
    be ready for ui.output_markdown.
    """
    if not isinstance(header, list):
        raise TypeError("Header must be a list.")
    if not any(isinstance(h, str) for h in header):
        raise TypeError("Header elements must be strings.")
    if not isinstance(rows, list):
        raise TypeError("Rows must be a list.")
    if not any(isinstance(r, list) for r in rows):
        raise TypeError("Row elements must be lists.")

    header_style = "padding: 5px; font-size: 13px; font-weight: heavy; text-align: center; " "border: 1px solid grey;"
    cell_style = "padding: 5px; font-size: 12px; border: 1px solid gray; " "text-align: center;"

    row_template = """<tr>
{row}
</tr>"""
    table_headers = "\n".join([f'<th style="{header_style}">{head}</th>' for head in header])
    table_header = row_template.format(row=table_headers)
    table_rows = "\n".join(
        [row_template.format(row="\n".join([f'<td style="{cell_style}">{cell}</td>' for cell in row])) for row in rows]
    )

    template = f"""<table>
{table_header}
{table_rows}
</table>
"""
    return template
