import logging
from typing import Optional

from ._client import PxmAppliance

logger = logging.getLogger(__name__)


def initialize(*, address: str, timeout: Optional[int] = 30) -> PxmAppliance:
    """ Create a PxM Platform adaptor. This adaptor should be passed in to functions
    from the other modules in this library, such as the `users` and `devices` modules.

    :param address: The hostname or IP address of the PxM Platform to connect to.
    :param timeout: Optional. The HTTP timeout to use in all API calls in seconds. Defaults to 30.

    :returns: An :ref:`record_types:Appliance Adaptor`.

    See the :ref:`index:Example Script` for a more comprehensive example of how the adaptor is used.

    .. code-block:: python

        pxm_platform = client.initialize(address='my-pxm.corporate.net', timeout=15)

    """
    return PxmAppliance(address=address, timeout=timeout)
