from ppa_tools.control_flow import exception_translate


class NetworkError(Exception):
    pass


class PxmApiError(Exception):
    def __init__(self, *, hint, details, code, message, status_code):
        # Example 400 error from the PxM Appliance API:
        # {
        #   'hint': None,
        #   'details': None,
        #   'code': '42703',
        #   'message':
        #   'column view:active_directories.codpiece does not exist'
        # }
        self.hint = hint
        self.details = details
        self.code = code
        self.message = message
        self.status_code = status_code

    def __str__(self):
        return (
            f"({self.status_code}) hint = {self.hint}, "
            f"details = {self.details}, code = {self.code}, "
            f"message = {self.message}"
        )


class UnhandledRecordData(Exception):
    pass


class NoSuchObject(Exception):
    pass


class NoAccountSecrets(Exception):
    pass


class SecretDoesNotExist(Exception):
    pass


class ParameterError(Exception):
    pass


def raise_on_empty(exception_msg):
    return exception_translate({IndexError: NoSuchObject(exception_msg)})
