from typing import List, Union

from typeguard import typechecked

from . import exceptions, query_formatters, _client
from ._records import create, Profile

ENDPOINT = "profiles"


@typechecked
@create(Profile)
def get_all(pxm: _client.PxmAppliance) -> List[Profile]:
    return _client._all(pxm, ENDPOINT)


@typechecked
@create(Profile)
def search(pxm: _client.PxmAppliance, **search_params: str) -> List[Profile]:
    return _client._search(pxm, ENDPOINT, **search_params)  # type: ignore


@typechecked
@create(Profile)
def get_by_id(pxm: _client.PxmAppliance, profile_id: Union[int, str]) -> Profile:
    with exceptions.raise_on_empty(f"No {ENDPOINT} record found on the PxM Platform with id {profile_id}."):
        return _client._search(pxm, ENDPOINT, id=query_formatters._eq(profile_id))[0]


@typechecked
@create(Profile)
def get_by_name(pxm: _client.PxmAppliance, name: str) -> Profile:
    with exceptions.raise_on_empty(f"No {ENDPOINT} record found on the PxM Platform with name {name}."):
        return _client._search(pxm, ENDPOINT, name=query_formatters._eq(name))[0]


@typechecked
@create(Profile)
def get_by_property(pxm: _client.PxmAppliance, *, name: str, value: Union[int, str]) -> List[Profile]:
    return _client._search(pxm, ENDPOINT, **{name: query_formatters._eq(value)})
