from typing import Union, Optional, Tuple

from . import exceptions
from ._records import SSHKey, Secret


def _unpack(raw_secrets_data: dict) -> Tuple[str, Optional[dict]]:
    def _get_mandatory_value(key):
        try:
            return raw_secrets_data[key]
        except KeyError:
            raise exceptions.UnhandledRecordData(
                f"Cannot create a secret record without attribute {key}. Secret only contains "
                f"the following attributes: {list(raw_secrets_data.keys())}."
            )

    return (_get_mandatory_value("account_username"), _get_mandatory_value("secrets") or None)


def _create(account_id: Union[int, str], account_username: str, revealed_secrets: Optional[dict]) -> Secret:
    return Secret(
        account_id=account_id,
        account_username=account_username,
        password=revealed_secrets.get("password"),
        ssh_key=SSHKey(**revealed_secrets["ssh_key"]) if revealed_secrets.get("ssh_key") else None,
    )
